@@ -11,7 +11,7 @@ use Exporter qw(import);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-03-02'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '1.020'; # VERSION
+our $VERSION = '1.021'; # VERSION
 
 our @EXPORT_OK = qw(
                        gen_csv_util
@@ -258,11 +258,14 @@ sub _array2hash {
 }
 
 sub _select_fields {
-    my ($fields, $field_idxs, $args) = @_;
+    my ($fields, $field_idxs, $args, $default_to_select_all) = @_;
 
     my @selected_fields;
 
+    my $select_field_options_used;
+
     if (defined $args->{include_field_pat}) {
+        $select_field_options_used++;
         for my $field (@$fields) {
             if ($field =~ $args->{include_field_pat}) {
                 push @selected_fields, $field;
@@ -270,10 +273,12 @@ sub _select_fields {
         }
     }
     if (defined $args->{exclude_field_pat}) {
+        $select_field_options_used++;
         @selected_fields = grep { $_ !~ $args->{exclude_field_pat} }
             @selected_fields;
     }
     if (defined $args->{include_fields}) {
+        $select_field_options_used++;
       FIELD:
         for my $field (@{ $args->{include_fields} }) {
             unless (defined $field_idxs->{$field}) {
@@ -285,6 +290,7 @@ sub _select_fields {
         }
     }
     if (defined $args->{exclude_fields}) {
+        $select_field_options_used++;
       FIELD:
         for my $field (@{ $args->{exclude_fields} }) {
             unless (defined $field_idxs->{$field}) {
@@ -295,6 +301,10 @@ sub _select_fields {
         }
     }
 
+    if (!$select_field_options_used && $default_to_select_all) {
+        @selected_fields = @$fields;
+    }
+
     if ($args->{show_selected_fields}) {
         return [200, "OK", \@selected_fields];
     }
@@ -1891,7 +1901,7 @@ App::CSVUtils - CLI utilities related to CSV
 
 =head1 VERSION
 
-This document describes version 1.020 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2023-03-02.
+This document describes version 1.021 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2023-03-02.
 
 =head1 DESCRIPTION
 
