@@ -8,7 +8,7 @@ use Log::ger;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-03-02'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '1.020'; # VERSION
+our $VERSION = '1.021'; # VERSION
 
 use App::CSVUtils qw(
                         gen_csv_util
@@ -37,8 +37,19 @@ where `rownum` begins at 1 (for header row), `fieldnum` begins at 1 (first
 field), `value1` is the value in first CSV file, `value2` is the value in the
 second CSV file.
 
+Other notes:
+
+* If none of the field selection options are used, it means all fields are
+  included (equivalent to `--include-all-fields`).
+
+* Field selection will be performed on the first CSV file, then the indexes will
+be used for the second CSV file.
+
 _
     add_args => {
+        %App::CSVUtils::argspecsopt_field_selection,
+        %App::CSVUtils::argspecsopt_show_selected_fields,
+
         detail => {
             summary => 'Report all differences instead of just the first one',
             schema => 'true*',
@@ -67,6 +78,20 @@ _
             schema => 'bool*',
         },
     },
+    examples => [
+        {
+            summary => 'Compare two identical files, will output nothing and exits 0',
+            argv => ['file.csv', 'file.csv'],
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
+        {
+            summary => 'Compare two CSV files case-insensitively (-i), show detailed report (-l)',
+            argv => ['file1.csv', 'file2.csv', '-il'],
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
+    ],
 
     reads_multiple_csv => 1,
 
@@ -85,12 +110,30 @@ _
 
         # we add the following keys to the stash
         $r->{all_input_rows} = [[], []]; # including header row. format: [ [row1 of csv1, row2 of csv1...], [row1 of csv2, row2 of csv2, ...] ]
+        $r->{selected_fields_idx_array_sorted} = undef;
     },
 
     on_input_header_row => sub {
         my $r = shift;
 
         push @{ $r->{all_input_rows}[ $r->{input_filenum}-1 ] }, $r->{input_fields};
+
+        if ($r->{input_filenum} == 1) {
+            # set selected_fields_idx_array_sorted
+            my $res = App::CSVUtils::_select_fields($r->{input_fields}, $r->{input_fields_idx}, $r->{util_args}, 1);
+            die $res unless $res->[0] == 100;
+            my $selected_fields = $res->[2][0];
+            my $selected_fields_idx_array = $res->[2][1];
+            die [412, "At least one field must be selected"]
+                unless @$selected_fields;
+            $r->{selected_fields_idx_array_sorted} = [sort { $b <=> $a } @$selected_fields_idx_array];
+
+            if ($r->{util_args}{show_selected_fields}) {
+                $r->{wants_skip_files}++;
+                $r->{result} = [200, "OK", $selected_fields];
+                return;
+            }
+        }
     },
 
     on_input_data_row => sub {
@@ -124,7 +167,8 @@ _
 
         my $numrows_min = $numrows1 < $numrows2 ? $numrows1 : $numrows2;
         for my $rownum (1 .. $numrows_min) {
-            for my $fieldnum (1 .. $numfields1) {
+            for my $j (@{ $r->{selected_fields_idx_array_sorted} }) {
+                my $fieldnum = $j+1;
                 my $origvalue1 = my $value1 = $r->{all_input_rows}[0][ $rownum-1 ][ $fieldnum-1 ];
                 my $origvalue2 = my $value2 = $r->{all_input_rows}[1][ $rownum-1 ][ $fieldnum-1 ];
 
@@ -187,7 +231,7 @@ App::CSVUtils::csv_cmp - Compare two CSV files value by value
 
 =head1 VERSION
 
-This document describes version 1.020 of App::CSVUtils::csv_cmp (from Perl distribution App-CSVUtils), released on 2023-03-02.
+This document describes version 1.021 of App::CSVUtils::csv_cmp (from Perl distribution App-CSVUtils), released on 2023-03-02.
 
 =head1 FUNCTIONS
 
@@ -200,6 +244,24 @@ Usage:
 
 Compare two CSV files value by value.
 
+Examples:
+
+=over
+
+=item * Compare two identical files, will output nothing and exits 0:
+
+ csv_cmp(input_filenames => ["file.csv", "file.csv"]);
+
+=item * Compare two CSV files case-insensitively (-i), show detailed report (-l):
+
+ csv_cmp(
+     input_filenames => ["file1.csv", "file2.csv"],
+   detail => 1,
+   ignore_case => 1
+ );
+
+=back
+
 This utility is modelled after the Unix command C<cmp>; it compares two CSV files
 value by value and ignore quoting (and can be instructed to ignore whitespaces,
 case difference).
@@ -218,6 +280,18 @@ where C<rownum> begins at 1 (for header row), C<fieldnum> begins at 1 (first
 field), C<value1> is the value in first CSV file, C<value2> is the value in the
 second CSV file.
 
+Other notes:
+
+=over
+
+=item * If none of the field selection options are used, it means all fields are
+included (equivalent to C<--include-all-fields>).
+
+=item * Field selection will be performed on the first CSV file, then the indexes will
+be used for the second CSV file.
+
+=back
+
 This function is not exported.
 
 Arguments ('*' denotes required arguments):
@@ -228,6 +302,14 @@ Arguments ('*' denotes required arguments):
 
 Report all differences instead of just the first one.
 
+=item * B<exclude_field_pat> => I<re>
+
+Field regex pattern to exclude, takes precedence over --field-pat.
+
+=item * B<exclude_fields> => I<array[str]>
+
+Field names to exclude, takes precedence over --fields.
+
 =item * B<ignore_case> => I<bool>
 
 Ignore case difference.
@@ -240,10 +322,22 @@ Ignore leading whitespaces.
 
 Ignore trailing whitespaces.
 
+=item * B<ignore_unknown_fields> => I<bool>
+
+When unknown fields are specified in --include-field (--field) or --exclude-field options, ignore them instead of throwing an error.
+
 =item * B<ignore_ws> => I<bool>
 
 Ignore leading & trailing whitespaces.
 
+=item * B<include_field_pat> => I<re>
+
+Field regex pattern to select, overidden by --exclude-field-pat.
+
+=item * B<include_fields> => I<array[str]>
+
+Field names to include, takes precedence over --exclude-field-pat.
+
 =item * B<inplace> => I<true>
 
 Output to the same file as input.
@@ -407,6 +501,10 @@ Whether to override existing output file.
 
 Do not report, just signal via exit code.
 
+=item * B<show_selected_fields> => I<true>
+
+Show selected fields and then immediately exit.
+
 
 =back
 
